import { Observable } from 'rxjs';
export interface RequestBodyBase {
    mediaType: string;
}
export interface FileRequestBody extends RequestBodyBase {
    type: 'file';
    fileName: string;
}
export declare const fileBody: (fileName: string, mediaType?: string) => FileRequestBody;
export interface TextRequestBody extends RequestBodyBase {
    type: 'text';
    text: string;
}
export declare const textBody: (text: string, mediaType?: string) => TextRequestBody;
export interface JsonRequestBody<T> extends RequestBodyBase {
    type: 'json';
    value: T;
}
export declare const jsonBody: <T>(value: T, mediaType?: string) => JsonRequestBody<T>;
export interface BytesRequestBody extends RequestBodyBase {
    type: 'bytes';
    value: androidNative.Array<number>;
}
export declare const bytesBody: (value: androidNative.Array<number>, mediaType?: string) => BytesRequestBody;
export declare type MultiPartMediaType = 'multipart/alternative' | 'multipart/mixed' | 'multipart/digest' | 'multipart/parallel' | 'multipart/form-data';
export interface FormValuePart {
    type: 'form-value';
    name: string;
    value: string;
}
export declare const formValuePart: (name: string, value: string) => FormValuePart;
export interface FormFilePart<T> {
    type: 'form-file';
    name: string;
    fileName: string;
    body: RequestBody<T>;
}
export declare const formFilePart: <T>(name: string, fileName: string, body: RequestBody<T>) => FormFilePart<T>;
export interface GenericPart<T> {
    type: 'part';
    name: string;
    body: RequestBody<T>;
    headers?: HttpRequestHeaders;
}
export declare const part: <T>(name: string, body: RequestBody<T>, headers?: HttpRequestHeaders) => GenericPart<T>;
export declare type MultiPartRequestPart<T> = FormValuePart | FormFilePart<T> | GenericPart<T>;
export declare type MultiPartRequestPartTuple<T> = {
    [P in keyof T]: MultiPartRequestPart<T[P]>;
};
export interface MultiPartRequestBody<A extends readonly unknown[]> extends RequestBodyBase {
    type: 'multipart';
    mediaType: MultiPartMediaType;
    parts: readonly [...MultiPartRequestPartTuple<A>];
}
export declare const multiPartBody: <A extends readonly unknown[]>(parts: MultiPartRequestPartTuple<A>, mediaType?: MultiPartMediaType) => MultiPartRequestBody<A>;
export declare type RequestBody<T> = FileRequestBody | TextRequestBody | JsonRequestBody<T> | BytesRequestBody | MultiPartRequestBody<T extends unknown[] ? T : never>;
export declare type HttpRequestMethod = 'GET' | 'POST';
export declare type HttpRequestHeaderValue = string | string[];
export interface HttpRequestDictionaryHeaders {
    [header: string]: HttpRequestHeaderValue;
}
export declare type HttpRequestHeaders = HttpRequestDictionaryHeaders;
export interface HttpResponseHeaders {
    [header: string]: string[];
}
export declare const loopHeaders: (headers: HttpRequestHeaders, callback: (headerName: string, headerValue: string) => void) => void;
export declare const printHeaders: (headers: HttpRequestHeaders, indentation?: string) => string;
export declare const printContentSummary: <T>(body: RequestBody<T>) => string;
export interface IHttpRequest<T> {
    url: string;
    method: HttpRequestMethod;
    headers?: HttpRequestHeaders;
    content?: RequestBody<T>;
}
export interface IHttpResponse {
    statusCode: number;
    headers: HttpResponseHeaders;
    text(): Observable<string>;
    json<T>(): Observable<T>;
    bytes(): Observable<androidNative.Array<number>>;
    save(fileName: string): Observable<void>;
}
export interface IHttp {
    request<T>(options: IHttpRequest<T>): Observable<IHttpResponse>;
}
declare type Logger = (...args: (string | (() => string))[]) => void;
export declare type CreateHttp = (baseUrl: string, log?: Logger) => IHttp;
export declare const NOOP: () => void;
export declare const getLogger: (log: Logger | undefined) => Logger;
export declare function forRelativeUrl(relativeUrl: string, http: IHttp): IHttp;
export declare class HttpError extends Error {
    response?: IHttpResponse;
    constructor(message?: string);
}
export declare class TransientError extends HttpError {
    constructor(message?: string);
}
export declare const getResponseError: (statusCode: number) => TransientError | HttpError | null;
export {};
